import React from 'react';
import { Select } from 'antd';

/**
 * 转换普通查询函数
 * @param {*} fn 
 * @param {*} params
 * @returns 
 */
export function transformQuery(fn, { searchKey = 'name', labelKey = 'name', valueKey = 'id' }) {
  return s => {
    const pageSize = !s ? 10 : 100;
    return fn({ pageSize, [searchKey]: s }).then(res => {
      return (res.records || []).map(x => ({...x, label: x[labelKey], value: x[valueKey]}));
    })
  }
}

/**
 * 远程搜索下拉框
 */
export default (props) => {
  const { request, onChange, ...leftProps } = props;

  // [{label, value}]
  const [list, setList] = React.useState([]);

  const onSearch = (searchValue) => {
    request(searchValue).then(setList);
  }

  const handleChange = (val) => {
    const obj = list.filter(x => x.value === val)[0];
    onChange(val, obj);
  }

  React.useEffect(() => {
    onSearch();
  }, []);

  return (
    <Select
      showSearch
      allowClear
      defaultActiveFirstOption={false}
      showArrow={false}
      filterOption={false}
      onSearch={onSearch}
      onChange={handleChange}
      notFoundContent={null}
      options={list}
      {...leftProps}
    />
  )
}
