import React from 'react';
import { Button, Card, Table, Space, Popconfirm } from 'antd';
import useBool from '@/utils/hooks/useBool';
import { getTaCheckItemQu, deleteTaCheckItemQu } from '@/service/tacheckitemqu';
import QuForm from './QuForm';

export default (props) => {
  const { itemId, itemType = 'loc', onChange } = props;

  const [open, setOpen] = React.useState(false);
  const [list, setList] = React.useState([]);
  const [curItem, setCurItem] = React.useState();
  const [loading, startLoading, stopLoading] = useBool();

  const totalScore = React.useMemo(() => {
    return list?.map((x) => x.maxScore).reduce((total, num) => total + num, 0);
  }, [list]);

  const columns = [
    {
      title: '序号',
      dataIndex: 'sortNo',
      key: 'sortNo',
      width: itemType === 'loc' ? 100 : undefined,
    },
    itemType !== 'loc' &&
    {
      title: '题型',
      dataIndex: 'quType',
      key: 'quType',
      render: t => !t ? '-' : (t == 'radio' ? '选择' : '填空'),
    },
    {
      title: '题干',
      dataIndex: 'title',
      key: 'title',
    },
    {
      title: '分值',
      dataIndex: 'maxScore',
      key: 'maxScore',
      width: itemType === 'loc' ? 100 : undefined,
    },
    {
      title: '操作',
      key: 'options',
      width: itemType === 'loc' ? 100 : 200,
      render: (_, row) => {
        return (
          <Space>
            <Button type="link" onClick={() => onEdit(row)}>编辑</Button>
            <Popconfirm
              title="确认进行删除操作?"
              onConfirm={() => onDelete(row)}
            >
              <Button type='link' danger >删除</Button>
            </Popconfirm>
          </Space>
        )
      }
    },
  ].filter(Boolean)

  const onAdd = () => {
    setCurItem();
    setOpen(true);
  }

  const onEdit = (qu) => {
    setCurItem(qu);
    setOpen(true);
  }

  const onDelete = (qu) => {
    if (qu?.quId) {
      deleteTaCheckItemQu(qu.quId).then(() => {
        setList(list.filter(x => x.quId !== qu.quId));
      })
    } else {
      setList(list.filter(x => x.quId !== qu.quId));
    }
  }

  const onFinish = (res) => {
    let found = false;
    const newList = list.map(item => {
      if (item.quId === res.quId) {
        found = true;
        return res;
      } else {
        return item
      }
    });

    if (!found) {
      newList.push(res);
    }

    setList(newList);

    if (onChange) {
      onChange();
    }
  }

  React.useEffect(() => {
    if (itemId) {
      startLoading();
      getTaCheckItemQu({ pageSize: 500, itemId }).then((res) => {
        stopLoading();
        setList(res.records);
      }).catch(() => {
        stopLoading();
      });
    }
  }, [itemId]);

  return (
    <Card
      title={`试题列表 (总分 ${totalScore})`}
      extra={
        itemType == 'loc' ?
          <Button type="link" disabled={!itemId} onClick={onAdd}>新增</Button> :
          <Button type="primary" ghost disabled={!itemId} onClick={onAdd}>新增</Button>
      }
    >
      <Table
        bordered
        rowKey="quId"
        loading={loading}
        columns={columns}
        dataSource={list}
        pagination={false}
      />
      <QuForm
        open={open}
        itemId={itemId}
        quInfo={curItem}
        itemType={itemType}
        onOpenChange={setOpen}
        onChange={onFinish}
      />
    </Card>
  )
}
