import React from "react";
import { useNavigate } from "react-router-dom";
import { queryTable } from "@/utils/request";
import { ProTable } from "@ant-design/pro-components";
import { Button, message, Popconfirm } from "antd";
import { getTdLocType, deleteTdLocType } from "@/service/tdloctype";
import Page from "@/components/Page";

const queryTdLocTypeList = queryTable(getTdLocType);

export default (props) => {
  const actionRef = React.useRef();
  const navigate = useNavigate();

  // const updateStatus = (user) => {
  //   const status = user.status === 1 ? 0 : 1;
  //   const hide = message.loading("请稍候...", 0);
  //   updateUserStatus(user.id, status)
  //     .then((res) => {
  //       hide();
  //       actionRef.current.reload();
  //     })
  //     .catch(() => {
  //       hide();
  //     });
  // };
  const handleDelete = (id) => {
    if (id) {
      deleteTdLocType(id).then((res) => {
        actionRef.current.reload();
      });
    }
  };

  const columns = [
    {
      title: "分类名称",
      dataIndex: "name",
    },
    {
      title: "分类描述",
      dataIndex: "desc",
    },
    {
      title: "状态",
      dataIndex: "status",
      valueEnum: {
        1: {
          text: "正常",
          status: "Processing",
        },
        0: {
          text: "禁用",
          status: "Error",
        },
      },
    },
    {
      title: "操作",
      valueType: "option",
      width: 200,
      render: (_, record) => [
        <Button
          key={2}
          style={{ padding: 0 }}
          type="link"
          onClick={() => {
            navigate(`/dict/locType/edit?id=${record.typeId}`);
          }}
        >
          编辑
        </Button>,
        <Popconfirm
          key={3}
          title="您是否确认删除 ?"
          onConfirm={() => handleDelete(record.typeId)}
          okText="确定"
          cancelText="取消"
        >
          {/* manualPush */}
          <Button style={{ padding: 0 }} type="link">
            删除
          </Button>
        </Popconfirm>,
      ],
    },
  ];

  return (
    <Page>
      <ProTable
        actionRef={actionRef}
        rowKey="typeId"
        search={false}
        toolBarRender={() => [
          <Button
            key="1"
            type="primary"
            onClick={() => {
              navigate("/dict/locType/edit");
            }}
          >
            新增
          </Button>,
        ]}
        request={queryTdLocTypeList}
        columns={columns}
      />
    </Page>

  );
};
